==> dojo-1.9.4.tgz: package/cldr/nls/th/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-weekday": "วันในสัปดาห์",
	"dateFormatItem-GyMMMEd": "E d MMM G y",
	"dateFormatItem-MMMEd": "E d MMM",
	"eraNarrow": [
		"ฮ.ศ."
	],
	"days-format-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"dateFormat-long": "d MMMM G y",
	"months-format-wide": [
		"มุฮะร์รอม",
		"ซอฟาร์",
		"รอบี I",
		"รอบี II",
		"จุมาดา I",
		"จุมาดา II",
		"รอจับ",
		"ชะอะบาน",
		"รอมะดอน",
		"เชาวัล",
		"ดฮุุอัลกิดะห์",
		"ดฮุอัลฮิจจะห์"
	],
	"dateFormatItem-yyyyQQQ": "QQQ G y",
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "หลังเที่ยง",
	"dateFormat-full": "EEEEที่ d MMMM G y",
	"dateFormatItem-yyyyMEd": "E d/M/y G",
	"dateFormatItem-Md": "d/M",
	"field-era": "สมัย",
	"months-standAlone-wide": [
		"มุฮะร์รอม",
		"ซอฟาร์",
		"รอบี I",
		"รอบี II",
		"จุมาดา I",
		"จุมาดา II",
		"รอจับ",
		"ชะอะบาน",
		"รอมะดอน",
		"เชาวัล",
		"ดฮุุอัลกิดะห์",
		"ดฮุอัลฮิจจะห์"
	],
	"quarters-format-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"timeFormat-long": "H นาฬิกา mm นาที ss วินาที z",
	"field-year": "ปี",
	"field-hour": "ชั่วโมง",
	"months-format-abbr": [
		"มุฮัร.",
		"เศาะ.",
		"รอบี 1",
		"รอบี 2",
		"ญุมา 1",
		"ญุมา 2",
		"เราะ.",
		"ชะอ์.",
		"เราะมะ.",
		"เชาว.",
		"ซุลกิอฺ.",
		"ซุลหิจ."
	],
	"timeFormat-full": "H นาฬิกา mm นาที ss วินาที zzzz",
	"field-day-relative+0": "วันนี้",
	"field-day-relative+1": "พรุ่งนี้",
	"dateFormatItem-GyMMMd": "d MMM G y",
	"field-day-relative+2": "มะรืนนี้",
	"months-standAlone-abbr": [
		"มุฮัร.",
		"เศาะ.",
		"รอบี 1",
		"รอบี 2",
		"ญุมา 1",
		"ญุมา 2",
		"เราะ.",
		"ชะอ์.",
		"เราะมะ.",
		"เชาว.",
		"ซุลกิอฺ.",
		"ซุลหิจ."
	],
	"quarters-format-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"quarters-standAlone-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
	"days-standAlone-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"dateFormatItem-yyyyMMM": "MMM G y",
	"dateFormatItem-yyyyMMMd": "d MMM G y",
	"quarters-standAlone-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"eraAbbr": [
		"ฮ.ศ."
	],
	"field-minute": "นาที",
	"field-dayperiod": "ช่วงวัน",
	"days-standAlone-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"field-day-relative+-1": "เมื่อวาน",
	"dateTimeFormat-long": "{1}, {0}",
	"dayPeriods-format-narrow-am": "ก่อนเที่ยง",
	"field-day-relative+-2": "เมื่อวานซืน",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1}, {0}",
	"field-day": "วัน",
	"days-format-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"field-zone": "เขต",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "ปีที่แล้ว",
	"field-month-relative+-1": "เดือนที่แล้ว",
	"days-format-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"eraNames": [
		"ฮิจเราะห์ศักราช"
	],
	"days-format-narrow": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "เดือน",
	"days-standAlone-narrow": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"dayPeriods-format-wide-am": "ก่อนเที่ยง",
	"dateFormat-short": "d/M/y G",
	"field-second": "วินาที",
	"field-month-relative+0": "เดือนนี้",
	"field-month-relative+1": "เดือนหน้า",
	"dateFormatItem-Ed": "E d",
	"field-week": "สัปดาห์",
	"dateFormat-medium": "d MMM G y",
	"field-year-relative+0": "ปีนี้",
	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "ปีหน้า",
	"dayPeriods-format-narrow-pm": "หลังเที่ยง",
	"dateFormatItem-yyyyQQQQ": "QQQQ G y",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-GyMMM": "MMM G y",
	"field-week-relative+0": "สัปดาห์นี้",
	"field-week-relative+1": "สัปดาห์หน้า"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/th/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "ขณะนี้",
	"field-weekday": "วันในสัปดาห์",
	"field-wed-relative+0": "พุธนี้",
	"field-wed-relative+1": "พุธหน้า",
	"dateFormatItem-GyMMMEd": "E d MMM G y",
	"dateFormatItem-MMMEd": "E d MMM",
	"eraNarrow": [
		"ฮ.ศ."
	],
	"field-tue-relative+-1": "อังคารที่แล้ว",
	"days-format-short": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"dateFormat-long": "d MMMM G y",
	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
	"field-wed-relative+-1": "พุธที่แล้ว",
	"months-format-wide": [
		"มุฮะร์รอม",
		"ซอฟาร์",
		"รอบี I",
		"รอบี II",
		"จุมาดา I",
		"จุมาดา II",
		"รอจับ",
		"ชะอะบาน",
		"รอมะดอน",
		"เชาวัล",
		"ซุลกิอฺดะฮฺ",
		"ซุลหิจญะฮฺ"
	],
	"dateFormatItem-yyyyQQQ": "QQQ G y",
	"dayPeriods-format-wide-pm": "หลังเที่ยง",
	"dateFormat-full": "EEEEที่ d MMMM G y",
	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
	"field-thu-relative+-1": "พฤหัสที่แล้ว",
	"dateFormatItem-Md": "d/M",
	"field-era": "สมัย",
	"months-standAlone-wide": [
		"มุฮะร์รอม",
		"ซอฟาร์",
		"รอบี I",
		"รอบี II",
		"จุมาดา I",
		"จุมาดา II",
		"รอจับ",
		"ชะอะบาน",
		"รอมะดอน",
		"เชาวัล",
		"ซุลกิอฺดะฮฺ",
		"ซุลหิจญะฮฺ"
	],
	"quarters-format-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"timeFormat-long": "H นาฬิกา mm นาที ss วินาที z",
	"field-year": "ปี",
	"field-hour": "ชั่วโมง",
	"months-format-abbr": [
		"มุฮัร.",
		"เศาะ.",
		"รอบี 1",
		"รอบี 2",
		"ญุมา 1",
		"ญุมา 2",
		"เราะ.",
		"ชะอ์.",
		"เราะมะ.",
		"เชาว.",
		"ซุลกิอฺ.",
		"ซุลหิจ."
	],
	"field-sat-relative+0": "เสาร์นี้",
	"field-sat-relative+1": "เสาร์หน้า",
	"timeFormat-full": "H นาฬิกา mm นาที ss วินาที zzzz",
	"field-day-relative+0": "วันนี้",
	"field-thu-relative+0": "พฤหัสนี้",
	"field-day-relative+1": "พรุ่งนี้",
	"field-thu-relative+1": "พฤหัสหน้า",
	"dateFormatItem-GyMMMd": "d MMM G y",
	"field-day-relative+2": "มะรืนนี้",
	"months-standAlone-abbr": [
		"มุฮัร.",
		"เศาะ.",
		"รอบี 1",
		"รอบี 2",
		"ญุมา 1",
		"ญุมา 2",
		"เราะ.",
		"ชะอ์.",
		"เราะมะ.",
		"เชาว.",
		"ซุลกิอฺ.",
		"ซุลหิจ."
	],
	"quarters-format-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"quarters-standAlone-wide": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"dateFormatItem-yyyyMMM": "MMM G y",
	"dateFormatItem-yyyyMMMd": "d MMM G y",
	"field-sun-relative+0": "อาทิตย์นี้",
	"field-sun-relative+1": "อาทิตย์หน้า",
	"quarters-standAlone-abbr": [
		"ไตรมาส 1",
		"ไตรมาส 2",
		"ไตรมาส 3",
		"ไตรมาส 4"
	],
	"eraAbbr": [
		"ฮ.ศ."
	],
	"field-minute": "นาที",
	"field-dayperiod": "ช่วงวัน",
	"days-standAlone-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"dateFormatItem-d": "d",
	"field-day-relative+-1": "เมื่อวาน",
	"field-day-relative+-2": "เมื่อวานซืน",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-fri-relative+0": "ศุกร์นี้",
	"field-fri-relative+1": "ศุกร์หน้า",
	"field-day": "วัน",
	"days-format-wide": [
		"วันอาทิตย์",
		"วันจันทร์",
		"วันอังคาร",
		"วันพุธ",
		"วันพฤหัสบดี",
		"วันศุกร์",
		"วันเสาร์"
	],
	"field-zone": "เขตเวลา",
	"dateFormatItem-y": "G y",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "ปีที่แล้ว",
	"field-month-relative+-1": "เดือนที่แล้ว",
	"days-format-abbr": [
		"อา.",
		"จ.",
		"อ.",
		"พ.",
		"พฤ.",
		"ศ.",
		"ส."
	],
	"eraNames": [
		"ฮิจเราะห์ศักราช"
	],
	"days-format-narrow": [
		"อา",
		"จ",
		"อ",
		"พ",
		"พฤ",
		"ศ",
		"ส"
	],
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-month": "เดือน",
	"dateFormatItem-MMM": "LLL",
	"days-standAlone-narrow": [
		"อา",
		"จ",
		"อ",
		"พ",
		"พฤ",
		"ศ",
		"ส"
	],
	"field-tue-relative+0": "อังคารนี้",
	"field-tue-relative+1": "อังคารหน้า",
	"dayPeriods-format-wide-am": "ก่อนเที่ยง",
	"field-mon-relative+0": "จันทร์นี้",
	"field-mon-relative+1": "จันทร์หน้า",
	"dateFormat-short": "d/M/y G",
	"field-second": "วินาที",
	"field-sat-relative+-1": "เสาร์ที่แล้ว",
	"field-sun-relative+-1": "อาทิตย์ที่แล้ว",
	"field-month-relative+0": "เดือนนี้",
	"field-month-relative+1": "เดือนหน้า",
	"dateFormatItem-Ed": "E d",
	"field-week": "สัปดาห์",
	"dateFormat-medium": "d MMM G y",
	"field-year-relative+0": "ปีนี้",
	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
	"field-year-relative+1": "ปีหน้า",
	"dateFormatItem-yyyyM": "M/y G",
	"dateFormatItem-yyyyQQQQ": "QQQQ G y",
	"field-mon-relative+-1": "จันทร์ที่แล้ว",
	"dateFormatItem-GyMMM": "MMM G y",
	"field-week-relative+0": "สัปดาห์นี้",
	"field-week-relative+1": "สัปดาห์หน้า"
}
//end v1.x content
);
